@@ -1,33 +1,20 @@
-from parser_module import wiki
 from parser_libraries import functions as f
 from parser_libraries import SQL as SQL
 from bs4 import BeautifulSoup
-from selenium import webdriver
-import time
-import os
 
 
 COMPLEX_URL = 'https://ru.wikipedia.org/wiki/%D0%A1%D1%83%D0%B1%D1%8A%D0%B5%D0%BA%D1%82%D1%8B_%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D0%B9%D1%81%D0%BA%D0%BE%D0%B9_%D0%A4%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%B8'
 HOST = 'https://ru.wikipedia.org/'
 
 
-def get_yandex_html(link):
-    options = webdriver.FirefoxOptions()
-    options.add_argument('-headless')
-    res = os.path.abspath('geckodriver')
-    res = res[:res.rfind('parser_module_code')] + 'parser_main/geckodriver'
-    driver = webdriver.Firefox(executable_path=res, firefox_options=options)
-    driver.get(link)
-    time.sleep(2)
-    return driver.page_source
-
-
 def get_yandex_image(name):
+    info = SQL.get_con_info()
     link = 'https://yandex.ru/images/search?text=' + name[0] + '%20' + name[1] + '%20' + name[2]
-    html = get_yandex_html(link)
+    html = f.get_selenium_html(link, info[-1])
     soup = BeautifulSoup(html, 'html.parser')
-    print(soup)
-
+    soup = soup.find('a', class_='serp-item__link')
+    soup = soup.find('img').get('src')
+    return soup
 
 def get_wiki_person(link, work_id):
     html = f.get_html(link)
@@ -36,6 +23,7 @@ def get_wiki_person(link, work_id):
     if full_name.find('(') != -1:
         full_name = full_name[:full_name.find('(')]
     full_name = f.get_name(full_name)
+    print(full_name)
     soup = soup.find('table', class_='infobox')
     try:
         image_link = soup.find('td', class_='infobox-image').find('img').get('srcset')
@@ -44,9 +32,14 @@ def get_wiki_person(link, work_id):
         else:
             image_link = 'https:' + soup.find('td', class_='infobox-image').find('img').get('src')
     except:
-        image_link = get_yandex_image(full_name)
-    date = f.get_dig_date(soup.find('span', class_='bday').get_text(), 2)
-
+        image_link = 'https:/' + get_yandex_image(full_name)
+        image_link = image_link.replace(' ', '')
+        image_link = image_link.replace('///', '//')
+    soup = soup.find('span', class_='bday').get_text()
+    if soup != None:
+        date = f.get_dig_date(soup, 2)
+    else:
+        date = f.get_dig_date('01 01 1901')
     return {'position_id': work_id, 'first_name': full_name[1], 'middle_name': full_name[2], 'last_name': full_name[0],
             'bday': date['day'], 'bmonth': date['month'], 'byear': date['year'], 'image_link': image_link, 'link': link}
 
@@ -71,6 +64,31 @@ def get_page(link):
                     if title.find('страница отсутствует') == -1:
                         person_link = a.find('td').find('a').get('href')
                         people.append(get_wiki_person(HOST + person_link, 33))
+                    else:
+                        title = title.replace(' (страница отсутствует)', '')
+                        if title.find('(') != -1:
+                            title = title[:title.find('(')]
+                        if title.rfind(' ') == len(title) - 1:
+                            title = title[:-1]
+                        full_name = [title[:title.find(',')].lower(), title[title.find(',')+1:title.rfind(' ')].lower(), title[title.rfind(' ')+1:].lower()]
+                        print(full_name)
+                        for part in full_name:
+                            part = part.replace(' ', '')
+                        image_link = 'https:' + get_yandex_image(full_name)
+                        image_link = image_link.replace(' ', '')
+                        image_link = image_link.replace('///', '//')
+                        people.append({
+                                       'position_id': 33,
+                                       'first_name': full_name[1],
+                                       'middle_name': full_name[2],
+                                       'last_name': full_name[0],
+                                       'bday': 1,
+                                       'bmonth': 1,
+                                       'byear': 1901,
+                                       'image_link': image_link,
+                                       'link': link
+                                       }
+                                      )
         except:
             continue
     return people
@@ -92,9 +110,10 @@ def parser():
                 flag = False
         if flag:
             links.append(HOST + a.find('a').get('href'))
+    i = 1
     for link in links:
+        print(f'{i}/{len(links)+1}')
+        i+=1
         a = get_page(link)
         people.extend(a)
-    SQL.mySQL_save(people)
-
-parser()
+    return people
\ No newline at end of file
