@@ -1,7 +1,7 @@
 import os
 from parser_libraries import functions as f
 from bs4 import BeautifulSoup
-from parser_libraries import SQL as SQL
+
 
 URL_1 = "http://www.cdep.ru/index.php?id=32"
 URL_2 = "http://viperson.ru/search?query="
@@ -10,10 +10,8 @@ HOST = "http://viperson.ru"
 
 def get_person(html):
     soup = BeautifulSoup(html, 'html.parser')
-    name = soup.find('div', class_="contentBody customArea").find_next('span').get_text()
+    name = soup.find('div', class_="contentBody customArea").find_next('span').get_text().lower()
     name = f.get_name(name)
-    for i in range(len(name)):
-        name[i] = name[i].lower()
     return name
 
 
@@ -22,7 +20,6 @@ def get_content(URL, name):
     if search.status_code == 200:
         soup = BeautifulSoup(search.text, 'html.parser')
         href = soup.find('table', class_='pi-sup__table').find_next('td', class_='pi-sup__img-td').find_next('a', class_='pi-sup__img-box').get('href')
-        # desiredpage->
         link = HOST + href
         html = f.get_html(link)
         if html.status_code == 200:
@@ -62,8 +59,6 @@ def parser():
         people.append(person)
         if people == 1:
             return [{'code': 1, 'script': os.path.basename(__file__)}]
-        SQL.mySQL_save(people)
+        return people
     else:
-        return [{'code': 2, 'script': os.path.basename(__file__)}]
-
-
+        return [{'code': 2, 'script': os.path.basename(__file__)}]
\ No newline at end of file
